<template>
  <section
    v-show="graphicDesignStudio.shop_color && graphicDesignStudio.shop_style"
    :class="{ ['color' + graphicDesignStudio.shop_color]: true, ['layout' + graphicDesignStudio.shop_style]: true }"
    class="graphic-design-studio">
    <div class="shop-html">
      <div class="shop-body">
        <div class="headerwidthcontainer">
          <div id="topnavbar">
            <div
              v-if="graphicDesignStudio.admin"
              id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'graphic_design_studiomain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'graphic_design_studiomain')}"
                    class="tab">Home
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'graphic_design_studioaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'graphic_design_studioaccounting')}"
                    class="tab">Accounting</a>
                </router-link>
                <div class="clear"/>
              </ul>
            </div>
          </div>
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
          <div class="banner">
            <div id="shopname">{{ graphicDesignStudio.name }}</div>
            <div
              id="tagline"
              :class="{jumbotron: graphicDesignStudio.shop_style === 2}">
              <p>{{ graphicDesignStudio.description }}</p>
            </div>
          </div>
          <div class="banner-image" />
        </div>
        <div class="clear"/>
        <div class="contentwidthcontainer">
          <div class="thecontent">
            <div id="sidebar">
              <headlines />
              <div class="action-buttons-header" />
              <action-buttons
                v-if="Object.keys(graphicDesignStudio).length"
                :has-swiper="hasSwiper"
                :shop="graphicDesignStudio"/>
            </div>
              <router-view
                :shop="graphicDesignStudio"
                :stories="storyIdeas"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo" />
          </div>
          <div class="clear"/>
        </div>

      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      graphicDesignStudio: {},
      hasSwiper: app.computerSettings.swiper,
      storyIdeas: []
    };
  },
  created: function () {
    this.getData();
    this.poller();
  },
  beforeMount: function () {
    this.$router.push({name: "graphic_design_studiomain"});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "graphic_design_studio/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.graphicDesignStudio = Response;
            app.Message( "Successfully loaded the Graphic Design Studio!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    getStoryIdeas() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "kiosk/getStoryIdeas/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.storyIdeas = Response;
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    poller() {
      this.intervalID = setInterval(() => {
        this.getStoryIdeas();
      }, 10000);
    },
    simpleOne() {
      this.graphicDesignStudio.shop_style = 1;
      this.graphicDesignStudio.shop_color = 1;
    },
    simpleTwo() {
      this.graphicDesignStudio.shop_style = 1;
      this.graphicDesignStudio.shop_color = 2;
    },
    busyOne() {
      this.graphicDesignStudio.shop_style = 2;
      this.graphicDesignStudio.shop_color = 1;
    },
    busyTwo() {
      this.graphicDesignStudio.shop_style = 2;
      this.graphicDesignStudio.shop_color = 2;
    },
  },

};
</script>

<style lang="less">
.graphic-design-studio.layout1.color1 {
  /* Media Agency common */
  @sidebarcolor: #efefef;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #4b7c75;
  @topnavcolor: #68c4b5;
  @shoptitlecolor: #29282b;
  @logoborder: 0.5rem solid #fdda93;
  @shopdesccolor:#35353f;
  @homemsgcolor:#144a68;
  @navbgcolor: white;
  @tabfontcolor: #35353f;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:  #35353f;
  @buttonbackground:#3364b9;
  @buttonborder:#FFF;
  @buttonhoverbg:#00b4c2;
  @buttonp: #fff;
  @buttonborderhover: white;
  @factsbg:#fff;
  @factsh2: white;
  @factstitlebg:#66556e;
  @factslistcolor:#FFF;
  @factscolor: black;
  @actionbuttonheader: #43354a;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @mediaimage: url(/images/shop/graphicdesignstudio/L1C1.svg);


  @import '../../shared.less';
  @import './graphicDesignStudioLayout1.less';
}

</style>

<style lang="less">
.graphic-design-studio.layout1.color2 {
  /* Media Agency common */

  @sidebarcolor: #efefef;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #4ed0c1;
  @topnavcolor: #f29040;
  @shoptitlecolor: #29282b;
  @logoborder: 0.5rem solid #3a525a;
  @shopdesccolor: #35353f;
  @homemsgcolor:#7f0000;
  @navbgcolor: #9FF9E4;
  @tabfontcolor: #29282b;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#29282b;
  @buttonbackground:#264653;
  @buttonborder:#FFF;
  @buttonborderhover:#FFF;
  @buttonhoverbg:#2a9d8f;
  @buttonp: #fff;
  @factsbg:#fff;
  @factstitlebg:#3a525a;
  @factsh2:#fff;
  @factslistcolor:#ffff;
  @factscolor:#204045;
  @actionbuttonheader: #203b46;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @mediaimage: url(/images/shop/graphicdesignstudio/L1C2.svg);

  @import '../../shared.less';
  @import './graphicDesignStudioLayout1.less';
  }
  </style>

  <style lang="less">
  .graphic-design-studio.layout2.color1 {
  /* Media Agency common */

  @sidebarcolor: #efefef;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #1f1d1d;
  @maincontentbg: rgba(163, 212, 245, 1);
  @topnavcolor: #d5e9ec;
  @shoptitlecolor: #243773;
  @logoborder: 0.5rem solid #f24d29;
  @shopdesccolor:#35353f;
  @homemsgcolor:#144a68;
  @navbgcolor: #f3f7fa;
  @tabfontcolor: #35353f;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#35353f;
  @buttonbackground:#eb4d4d;
  @buttonborder:#fff;
  @buttonhoverbg:#85afd5;
  @buttonborderhover: white;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factsh2:#FFF;
  @factstitlebg: #243773;
  @factslistcolor:#ffff;
  @factscolor:#163B53;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @actionbuttonheader: #18254e;
  @mediaimage: url(/images/shop/graphicdesignstudio/L2C1.svg);

  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;

  @import '../../shared.less';
  @import './graphicDesignStudioLayout2.less';
}
</style>

<style lang="less">
.graphic-design-studio.layout2.color2 {
  /* Media Agency common */

  @sidebarcolor: #efefef;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #005f73;
  @maincontentbg: rgba(249, 222, 174, 1);
  @topnavcolor: #201d1d;
  @shoptitlecolor: #94d2bd;
  @logoborder: 0.5rem solid #9b2226;
  @shopdesccolor: white;
  @homemsgcolor:#020101;
  @navbgcolor: #201d1d;
  @tabfontcolor: white;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor: white;
  @buttonbackground:#eb4d4d;
  @buttonborder:#FFF;
  @buttonborderhover:#FFFF;
  @buttonhoverbg:#85afd5;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factstitlebg: #0a9396;
  @factsh2:#FFF;
  @factslistcolor:#fff;
  @factscolor:black;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @actionbuttonheader: #9b2226;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @mediaimage: url(/images/shop/graphicdesignstudio/L2C2.svg);


  @import '../../shared.less';
  @import './graphicDesignStudioLayout2.less';
}

</style>
